/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_FOUNDATION_PRESENTATIONTEXT_H
#define DRN_FOUNDATION_PRESENTATIONTEXT_H

#include <QtGlobal>

#include <iosfwd>

#include "foundation_export.h"


class QDate;
class QString;

namespace pecunia::currency
{

enum class Currency : quint16;
class Money;

}

namespace drn::foundation
{

struct LocaleAware;
struct WithCurrency;
struct SpaceCurrency;

DRN_FOUNDATION_EXPORT ::QString presentationText(const pecunia::currency::Currency& code);
DRN_FOUNDATION_EXPORT ::QString presentationText(
	const pecunia::currency::Currency& code,
	const SpaceCurrency& shouldBeSpaced
);
DRN_FOUNDATION_EXPORT ::QString presentationText(const pecunia::currency::Money& money);
DRN_FOUNDATION_EXPORT ::QString presentationText(
	const pecunia::currency::Money& money,
	const WithCurrency& shouldAddCurrency
);
DRN_FOUNDATION_EXPORT ::QString presentationText(
	const pecunia::currency::Money& money,
	const LocaleAware& isLocaleAware,
	const WithCurrency& shouldAddCurrency
);
DRN_FOUNDATION_EXPORT ::QString presentationText(
	const pecunia::currency::Money& money,
	const WithCurrency& shouldAddCurrency,
	const SpaceCurrency& shouldBeSpaced
);
DRN_FOUNDATION_EXPORT ::QString presentationText(
	const pecunia::currency::Money& money,
	const LocaleAware& isLocaleAware,
	const WithCurrency& shouldAddCurrency,
	const SpaceCurrency& shouldBeSpaced
);
DRN_FOUNDATION_EXPORT ::QString presentationText(const ::QDate& value);
DRN_FOUNDATION_EXPORT ::QString presentationText(const ::qint8& value);
DRN_FOUNDATION_EXPORT ::QString presentationText(const ::quint8& value);

}

DRN_FOUNDATION_EXPORT std::ostream& operator<<(std::ostream& o, const ::QString& value);
DRN_FOUNDATION_EXPORT std::ostream& operator<<(std::ostream& o, const ::QDate& value);

#endif
